// java wrapper for vtkStructuredGridReader object
//

package vtk;
import vtk.*;

public class vtkStructuredGridReader extends vtkDataReader
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetOutput_2();
  public vtkStructuredGrid GetOutput() {
    long temp = GetOutput_2();

    if (temp == 0) return null;
    return (vtkStructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetOutput_3(int id0);
  public vtkStructuredGrid GetOutput(int id0) {
    long temp = GetOutput_3(id0);

    if (temp == 0) return null;
    return (vtkStructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetOutput_4(vtkStructuredGrid id0);
  public void SetOutput(vtkStructuredGrid id0)
    { SetOutput_4(id0); }

  private native int ReadMetaData_5(vtkInformation id0);
  public int ReadMetaData(vtkInformation id0)
    { return ReadMetaData_5(id0); }

  public vtkStructuredGridReader() { super(); }

  public vtkStructuredGridReader(long id) { super(id); }
  public native long   VTKInit();

}
